/*
 ## Cypress FX3 Camera Kit header file (sensor.h)
 ## ===========================
 ##
 ##  Copyright Cypress Semiconductor Corporation, 2010-2012,
 ##  All Rights Reserved
 ##  UNPUBLISHED, LICENSED SOFTWARE.
 ##
 ##  CONFIDENTIAL AND PROPRIETARY INFORMATION
 ##  WHICH IS THE PROPERTY OF CYPRESS.
 ##
 ##  Use of this file is governed
 ##  by the license agreement included in the file
 ##
 ##     <install>/license/license.txt
 ##
 ##  where <install> is the Cypress software
 ##  installation root directory path.
 ##
 ## ===========================
*/

/* This file defines the parameters and the interface for the MT9M114 image
   sensor driver.
 */

#ifndef _INCLUDED_SENSOR_H_
#define _INCLUDED_SENSOR_H_

#include <cyu3types.h>

/* The SADDR line allows MT9M114 image sensor to select between two different I2C slave address.
   If the SADDR line is high, enable this #define to allow access to the correct I2C address for the sensor.
 */
/* #define SADDR_HIGH */

/* I2C Slave address for the image sensor. */
//#ifdef SADDR_HIGH
//#define SENSOR_ADDR_WR 0xBA             /* Slave address used to write sensor registers. */
//#define SENSOR_ADDR_RD 0xBB             /* Slave address used to read from sensor registers. */
//#else
//#define SENSOR_ADDR_WR 0x90             /* Slave address used to write sensor registers. */
//#define SENSOR_ADDR_RD 0x91             /* Slave address used to read from sensor registers. */
//#endif
// FPGA

#define SENSOR_ADDR_WR 0x78           /* Slave address used to write sensor registers. */
#define SENSOR_ADDR_RD 0x79           /* Slave address used to read from sensor registers. */


#define I2C_SLAVEADDR_MASK 0xFE         /* Mask to get actual I2C slave address value without direction bit. */

#define I2C_MEMORY_ADDR_WR 0xA0         /* I2C slave address used to write to an EEPROM. */
#define I2C_MEMORY_ADDR_RD 0xA1         /* I2C slave address used to read from an EEPROM. */

/* GPIO 22 on FX3 is used to reset the Image sensor. */
#define SENSOR_RESET_GPIO 22

/* Function    : SensorWrite2B
   Description : Write two bytes of data to image sensor over I2C interface.
   Parameters  :
                 slaveAddr - I2C slave address for the sensor.
                 highAddr  - High byte of memory address being written to.
                 lowAddr   - Low byte of memory address being written to.
                 highData  - High byte of data to be written.
                 lowData   - Low byte of data to be written.
 */
extern CyU3PReturnStatus_t
SensorWrite2B (
        uint8_t slaveAddr,
        uint8_t highAddr,
        uint8_t lowAddr,
        uint8_t highData,
        uint8_t lowData);

/* Function    : SensorWrite
   Description : Write arbitrary amount of data to image sensor over I2C interface.
   Parameters  :
                 slaveAddr - I2C slave address for the sensor.
                 highAddr  - High byte of memory address being written to.
                 lowAddr   - Low byte of memory address being written to.
                 count     - Size of write data in bytes. Limited to a maximum of 64 bytes.
                 buf       - Pointer to buffer containing data.
 */
extern CyU3PReturnStatus_t
SensorWrite (
        uint8_t slaveAddr,
        uint8_t highAddr,
        uint8_t lowAddr,
        uint8_t count,
        uint8_t *buf);

/* Function    : SensorRead2B
   Description : Read 2 bytes of data from image sensor over I2C interface.
   Parameters  :
                 slaveAddr - I2C slave address for the sensor.
                 highAddr  - High byte of memory address being written to.
                 lowAddr   - Low byte of memory address being written to.
                 buf       - Buffer to be filled with data. MSB goes in byte 0.
 */
extern CyU3PReturnStatus_t
SensorRead2B (
        uint8_t slaveAddr,
        uint8_t highAddr,
        uint8_t lowAddr,
        uint8_t *buf);

/* Function    : SensorRead
   Description : Read arbitrary amount of data from image sensor over I2C interface.
   Parameters  :
                 slaveAddr - I2C slave address for the sensor.
                 highAddr  - High byte of memory address being written to.
                 lowAddr   - Low byte of memory address being written to.
                 count     = Size of data to be read in bytes. Limited to a max of 64.
                 buf       - Buffer to be filled with data.
 */
extern CyU3PReturnStatus_t
SensorRead (
        uint8_t slaveAddr,
        uint8_t highAddr,
        uint8_t lowAddr,
        uint8_t count,
        uint8_t *buf);

/* Function    : SensorInit
   Description : Initialize the MT9M114 sensor.
   Parameters  : None
 */
extern void
SensorInit (
        void);

/* Function    : SensorReset
   Description : Reset the MT9M114 image sensor using FX3 GPIO.
   Parameters  : None
 */
extern void
SensorReset (
        void);

/* Function    : SensorChangeConfig
   Description : Update sensor configuration based on selected video parameters.
   Parameters  : None
 */
extern void
SensorChangeConfig (
        void);

/* Function     : SensorScaling_HD720p_30fps
   Description  : Configure the MT9M114 sensor for 720p 30 fps video stream.
   Parameters   : None
 */
extern void
SensorScaling_HD720p_30fps (
        void);

/* Function     : SensorScaling_VGA
   Description  : Configure the MT9M114 sensor for VGA video stream.
   Parameters   : None
 */
extern void
SensorScaling_VGA (
        void);

/* Function    : SensorI2cBusTest
   Description : Test whether the MT9M114 sensor is connected on the I2C bus.
   Parameters  : None
 */
extern uint8_t
SensorI2cBusTest (
        void);

/* Function    : SensorGetBrightness
   Description : Get the current brightness setting from the  sensor.
   Parameters  : None
 */
extern uint8_t
SensorGetBrightness (
        void);

/* Function    : SensorSetBrightness
   Description : Set the desired brightness setting on the  sensor.
   Parameters  :
                 brightness - Desired brightness level.
 */
extern void
SensorSetBrightness (
        uint8_t input);


/* Function    : SensorGetContrast
   Description : Get the current Contrast setting from the  sensor.
   Parameters  : None
 */


extern uint8_t
SensorGetPower (
        void);

/* Function    : SensorSetBrightness
   Description : Set the desired brightness setting on the  sensor.
   Parameters  :
                 brightness - Desired brightness level.
 */
extern void
SensorSetPower (
        uint8_t input);


/* Function    : SensorGetContrast
   Description : Get the current Contrast setting from the  sensor.
   Parameters  : None
 */

//
//
extern uint8_t
SensorGetContrast(
        void);

/* Function    : SensorSetContrast
   Description : Set the desired contrast setting on the MT9M114 sensor.
   Parameters  :
                 Contrast - Desired contrast level.
 */
extern void
SensorSetContrast (
        uint8_t input);




//Hue

extern uint16_t
SensorGetHue(
        void);


extern void
SensorSetHue (
        uint16_t input);








extern uint8_t
SensorGetAnalog(
        void);

/* Function    : SensorSetContrast
   Description : Set the desired contrast setting on the MT9M114 sensor.
   Parameters  :
                 Contrast - Desired contrast level.
 */
extern void
SensorSetAnalog (
        uint8_t input);




//Status

extern uint8_t
SensorGetStatus(
        void);


extern void
SensorSetStatus (
        uint8_t input);





//Saturation

extern uint8_t
SensorGetSaturation(
        void);


extern void
SensorSetSaturation (
        uint8_t input);



//Gamma

extern uint8_t
SensorGetGamma(
        void);


extern void
SensorSetGamma (
        uint8_t input);


//Sharpness

extern uint8_t
SensorGetSharpness(
        void);


extern void
SensorSetSharpness (
        uint8_t input);



//Backlight Compensation

extern uint8_t
SensorGetBacklightComp(
        void);


extern void
SensorSetBacklightComp (
        uint8_t input);



//Auto hue

extern uint8_t
SensorGetAutoHue(
        void);


extern void
SensorSetAutoHue (
        uint8_t input);


//Gain

extern uint8_t
SensorGetGain(
        void);


extern void
SensorSetGain (
        uint8_t input);


//White Balance

extern uint8_t
SensorGetWhiteBalance(
        void);


extern void
SensorSetWhiteBalance (
        uint8_t input);


//Digital Multipler Limit

extern uint16_t
SensorGetDigMultiLim(
        void);


extern void
SensorSetDigMultiLim (
        uint16_t input);


//Digital Multipler

extern uint16_t
SensorGetDigMulti(
        void);


extern void
SensorSetDigMulti (
        uint16_t input);


#endif /* _INCLUDED_SENSOR_H_ */

/*[]*/

